import * as React from "react";
import * as PropTypes from "prop-types";
import { RevealEffectProps } from "../RevealEffect";
export interface ListItem {
    /**
     * set react node to item.
     */
    itemNode?: React.ReactNode;
    /**
     * set to disabled.
     */
    disabled?: boolean;
    /**
     * set to focused.
     */
    focus?: boolean;
    /**
     * set to style to item node.
     */
    style?: React.CSSProperties;
    /**
     * add onClick event callback.
     */
    onClick?: (e?: React.MouseEvent<HTMLDivElement>) => void;
}
export interface DataProps {
    /**
     * ListSource Data.
     */
    listSource?: ListItem[] | React.ReactNode[];
    /**
     * `listItemStyle` will applied to all listItem.
     */
    listItemStyle?: React.CSSProperties;
    /**
     * onChoose ListItem `callback`.
     */
    onChooseItem?: (itemIndex?: number) => void;
    /**
     * default focus List Item by `Index`.
     */
    defaultFocusListIndex?: number;
    /**
     * Set Custom Background.
     */
    background?: string;
    /**
     * Set RevealEffect, check the styles/reveal-effect.
     */
    revealConfig?: RevealEffectProps;
    /**
     * Set reveal-effect enable resize event.
     */
    enableResizeObserver?: boolean;
}
export interface ListViewProps extends DataProps, React.HTMLAttributes<HTMLDivElement> {
}
export interface ListViewState {
    focusIndex?: number;
}
export declare class ListView extends React.Component<ListViewProps, ListViewState> {
    static defaultProps: ListViewProps;
    state: ListViewState;
    static contextTypes: {
        theme: PropTypes.Requireable<object>;
    };
    context: {
        theme: ReactUWP.ThemeType;
    };
    rootElm: HTMLDivElement;
    styles: {
        [key: string]: React.CSSProperties;
    };
    componentWillReceiveProps(nextProps: ListViewProps): void;
    getItemNode: (itemNode: any, index: number, disabled?: boolean, focus?: boolean, style?: React.CSSProperties, onClick?: () => void) => JSX.Element;
    render(): JSX.Element;
}
export default ListView;
